'''
Licensed under the Universal Permissive License v 1.0 as shown at 
https://oss.oracle.com/licenses/upl/.
 Copyright (c) 2023, 2025, Oracle and/or its affiliates. 

Convenience APIs to ease the creation of connection with Types and JDBC Drivers 
supported by data transforms.
'''
from enum import Enum

#Enum type of all the supported connection types
#This is generated code (Oracle Data Transforms)
# pylint: disable=invalid-name,too-few-public-methods
class ConnectionTypes(Enum):
    """Supported connectors in DataTransforms"""
    ORACLE = "ORACLE"
    ORACLE_OBJECT_STORAGE = "ORACLE_OBJECT_STORAGE"
    ORACLE_NETSUITE = "ORACLE_NETSUITE"
    DELTA_SHARE = "DELTA_SHARE"
    INFORMIX = "INFORMIX"
    MICROSOFT_SQL_SERVER = "MICROSOFT_SQL_SERVER"
    MYSQL = "MYSQL"
    ORACLE_PEOPLE_SOFT = "ORACLE_PEOPLE_SOFT"
    ORACLE_EBS = "ORACLE_EBS"
    ORACLE_SIEBEL = "ORACLE_SIEBEL"
    ORACLE_BICS = "ORACLE_BICS"
    ORACLE_BI_CLOUD_CONNECTOR = "ORACLE_BI_CLOUD_CONNECTOR"
    ORACLE_FUSION_SALES = "ORACLE_FUSION_SALES"
    ORACLE_FUSION_SERVICE = "ORACLE_FUSION_SERVICE"
    ORACLE_FUSION_ERP = "ORACLE_FUSION_ERP"
    ORACLE_MARKETING_CLOUD = "ORACLE_MARKETING_CLOUD"
    HYPERSONIC_SQL = "HYPERSONIC_SQL"
    ORACLE_SALES_CLOUD = "ORACLE_SALES_CLOUD"
    ORACLE_SERVICE_CLOUD = "ORACLE_SERVICE_CLOUD"
    SALESFORCE_COM_DD = "SALESFORCE_COM_DD"
    SYBASE_AS_ENTERPRISE = "SYBASE_AS_ENTERPRISE"
    AMAZON_REDSHIFT = "AMAZON_REDSHIFT"
    IBM_DB2_400 = "IBM_DB2_400"
    MONGODB = "MONGODB"
    SYBASE_AS_ANYWHERE = "SYBASE_AS_ANYWHERE"
    SYBASE_AS_IQ = "SYBASE_AS_IQ"
    ORACLE_GOLDENGATE_OCI = "ORACLE_GOLDENGATE_OCI"
    EBAY = "EBAY"
    MAGENTO = "MAGENTO"
    ZENDESK = "ZENDESK"
    BIG_COMMERCE = "BIG_COMMERCE"
    WOO_COMMERCE = "WOO_COMMERCE"
    WORKDAY = "WORKDAY"
    XERO = "XERO"
    GOOGLE_ADS = "GOOGLE_ADS"
    GOOGLE_ANALYTICS = "GOOGLE_ANALYTICS"
    HUBSPOT = "HUBSPOT"
    MICROSOFT_DYNAMICS = "MICROSOFT_DYNAMICS"
    POSTGRESSQL = "POSTGRESSQL"
    TERADATA = "TERADATA"
    NETEZZA = "NETEZZA"
    CASSANDRA = "CASSANDRA"
    DATA_TRANSFORM = "DATA_TRANSFORM"
    ORACLE_FINANCIALS_CLOUD = "ORACLE_FINANCIALS_CLOUD"
    GOOGLE_BIGQUERY = "GOOGLE_BIGQUERY"
    AZURE_DATA_LAKE_STORAGE = "AZURE_DATA_LAKE_STORAGE"
    APACHE_SPARK_SQL = "APACHE_SPARK_SQL"
    GREENPLUM = "GREENPLUM"
    MYSQL_HEATWAVE = "MYSQL_HEATWAVE"
    JIRA = "JIRA"
    GITHUB = "GITHUB"
    TEAMCITY = "TEAMCITY"
    AHA = "AHA!"
    REST_SERVICE_WEB = "REST_SERVICE_WEB"
    SAP_S_4HANA = "SAP_S_4HANA"
    MICROSOFT_SHAREPOINT = "MICROSOFT_SHAREPOINT"
    CLOUDERA_IMPALA = "CLOUDERA_IMPALA"
    AZURE_BILLING = "AZURE_BILLING"
    AZURE_SQL_DATABASE = "AZURE_SQL_DATABASE"
    AZURE_SYNAPSE_ANALYTICS = "AZURE_SYNAPSE_ANALYTICS"
    PIVOTAL_HD = "PIVOTAL_HD"
    PIVOTAL_HDB = "PIVOTAL_HDB"
    IBM_DB2_WAREHOUSE = "IBM_DB2_WAREHOUSE"
    IBM_DB2_HOSTED = "IBM_DB2_HOSTED"
    SAP_BW_4HANA = "SAP_BW_4HANA"
    SAP_NETWEAVER = "SAP_NETWEAVER"
    FINANCIALFORCE = "FINANCIALFORCE"
    VEEVA_CRM = "VEEVA_CRM"
    DATASTAX = "DATASTAX"
    APACHE_HIVE = "APACHE_HIVE"
    CLOUDERA_CDH_HIVE = "CLOUDERA_CDH_HIVE"
    HORTONWORKS_HIVE = "HORTONWORKS_HIVE"
    IBM_BIGINSIGHTS = "IBM_BIGINSIGHTS"
    MAPR_HIVE = "MAPR_HIVE"
    AMAZON_EMR_HIVE = "AMAZON_EMR_HIVE"
    AMAZON_AURORA = "AMAZON_AURORA"
    ENTERPRISEDB = "ENTERPRISEDB"
    SNOWFLAKE = "SNOWFLAKE"
    GOOGLE_DRIVE = "GOOGLE_DRIVE"
    AWS_S3 = "AWS_S3"
    AZURE_COMPUTE = "AZURE_COMPUTE"
    AZURE_RESERVED_VM_INSTANCES = "AZURE_RESERVED_VM_INSTANCES"
    AZURE_RESOURCE_HEALTH = "AZURE_RESOURCE_HEALTH"
    SAGE = "SAGE"
    SQAURE = "SQAURE"
    WORDPRESS = "WORDPRESS"
    ZOHO_CRM = "ZOHO_CRM"
    AHREFS = "AHREFS"
    FOURSQUARE = "FOURSQUARE"
    GOOGLE_ADSENSE = "GOOGLE_ADSENSE"
    GOOGLE_CALENDAR = "GOOGLE_CALENDAR"
    GOOGLE_CAMPAIGN_MANAGER = "GOOGLE_CAMPAIGN_MANAGER"
    GOOGLE_CONTACTS = "GOOGLE_CONTACTS"
    GOOGLE_SEARCH_ADS_360 = "GOOGLE_SEARCH_ADS_360"
    KLAVIYO = "KLAVIYO"
    MAILCHIMP = "MAILCHIMP"
    MARKETO = "MARKETO"
    PAYPAL = "PAYPAL"
    QUICKBOOKS_ONLINE = "QUICKBOOKS_ONLINE"
    QUICKBOOKS_PAYMENTS = "QUICKBOOKS_PAYMENTS"
    QUORA_ADS = "QUORA_ADS"
    SEMRUSH = "SEMRUSH"
    TUMBLR = "TUMBLR"
    TWITTER = "TWITTER"
    VOLUSION = "VOLUSION"
    WISTIA = "WISTIA"
    CONFLUENCE_CLOUD = "CONFLUENCE_CLOUD"
    DOCUSIGN = "DOCUSIGN"
    SALESFORCE_CHATTER = "SALESFORCE_CHATTER"
    STRIPE = "STRIPE"
    YELP = "YELP"
    ZOOM = "ZOOM"
    QMETRY = "QMETRY"
    SHOPIFY = "SHOPIFY"
    IBM_DB2_UDB = "IBM_DB2_UDB"
    SERVICENOW = "SERVICENOW"




class ConnectionTypeDrivers:
    # pylint: disable=invalid-name,too-few-public-methods
    """JDBC Drivers for the supported connectors"""
    ORACLE = "oracle.jdbc.OracleDriver"
    ORACLE_OBJECT_STORAGE = "ORACLE_OBJECT_STORAGE"
    ORACLE_NETSUITE = "com.netsuite.jdbc.openaccess.OpenAccessDriver"
    DELTA_SHARE = "DELTA_SHARE"
    INFORMIX = "weblogic.jdbc.informix.InformixDriver"
    MICROSOFT_SQL_SERVER = "weblogic.jdbc.sqlserver.SQLServerDriver"
    MYSQL = "com.mysql.jdbc.Driver"
    ORACLE_PEOPLE_SOFT = "oracle.jdbc.OracleDriver"
    ORACLE_EBS = "oracle.jdbc.OracleDriver"
    ORACLE_SIEBEL = "oracle.jdbc.OracleDriver"
    ORACLE_BICS = "ORACLE_BICS"
    ORACLE_BI_CLOUD_CONNECTOR = "ORACLE_BI_CLOUD_CONNECTOR"
    ORACLE_FUSION_SALES = "ORACLE_FUSION_SALES"
    ORACLE_FUSION_SERVICE = "ORACLE_FUSION_SERVICE"
    ORACLE_FUSION_ERP = "ORACLE_FUSION_ERP"
    ORACLE_MARKETING_CLOUD = "weblogic.jdbc.eloqua.EloquaDriver"
    HYPERSONIC_SQL = "org.hsqldb.jdbc.JDBCDriver"
    ORACLE_SALES_CLOUD = "weblogic.jdbc.oraclesalescloud.OracleSalesCloudDriver"
    ORACLE_SERVICE_CLOUD = "weblogic.jdbc.oracleservicecloud.OracleServiceCloudDriver"
    SALESFORCE_COM_DD = "weblogic.jdbc.sforce.SForceDriver"
    SYBASE_AS_ENTERPRISE = "weblogic.jdbc.sybase.SybaseDriver"
    AMAZON_REDSHIFT = "weblogic.jdbc.redshift.RedshiftDriver"
    IBM_DB2_400 = "weblogic.jdbc.db2.DB2Driver"
    MONGODB = "weblogic.jdbc.mongodb.MongoDBDriver"
    SYBASE_AS_ANYWHERE = "weblogic.jdbc.sybase.SybaseDriver"
    SYBASE_AS_IQ = "weblogic.jdbc.sybase.SybaseDriver"
    ORACLE_GOLDENGATE_OCI = "ORACLE_GOLDENGATE_OCI"
    EBAY = "weblogic.jdbc.autorest.AutoRESTDriver"
    MAGENTO = "MAGENTO"
    ZENDESK = "weblogic.jdbc.autorest.AutoRESTDriver"
    BIG_COMMERCE = "weblogic.jdbc.autorest.AutoRESTDriver"
    WOO_COMMERCE = "WOO_COMMERCE"
    WORKDAY = "WORKDAY"
    XERO = "weblogic.jdbc.autorest.AutoRESTDriver"
    GOOGLE_ADS = "GOOGLE_ADS"
    GOOGLE_ANALYTICS = "weblogic.jdbc.googleanalytics.GoogleAnalyticsDriver"
    HUBSPOT = "weblogic.jdbc.hubspot.HubSpotDriver"
    MICROSOFT_DYNAMICS = "weblogic.jdbc.dynamics365.Dynamics365Driver"
    POSTGRESSQL = "weblogic.jdbc.postgresql.PostgreSQLDriver"
    TERADATA = "com.ncr.teradata.TeraDriver"
    NETEZZA = "org.netezza.Driver"
    CASSANDRA = "weblogic.jdbc.cassandra.CassandraDriver"
    DATA_TRANSFORM = "DATA_TRANSFORM"
    ORACLE_FINANCIALS_CLOUD = "oracle.odi.jdbc.driver.json.JsonDriver"
    GOOGLE_BIGQUERY = "weblogic.jdbc.googlebigquery.GoogleBigQueryDriver"
    AZURE_DATA_LAKE_STORAGE = "weblogic.jdbc.autorest.AutoRESTDriver"
    APACHE_SPARK_SQL = "weblogic.jdbc.sparksql.SparkSQLDriver"
    GREENPLUM = "weblogic.jdbc.greenplum.GreenplumDriver"
    MYSQL_HEATWAVE = "com.mysql.jdbc.Driver"
    JIRA = "weblogic.jdbc.jira.JiraDriver"
    GITHUB = "weblogic.jdbc.github.GitHubDriver"
    TEAMCITY = "weblogic.jdbc.teamcity.TeamCityDriver"
    AHA = "weblogic.jdbc.aha.AhaDriver"
    REST_SERVICE_WEB = "oracle.odi.jdbc.driver.json.JsonDriver"
    SAP_S_4HANA = "weblogic.jdbc.s4hana.S4HanaDriver"
    MICROSOFT_SHAREPOINT = "weblogic.jdbc.sharepoint.SharePointDriver"
    CLOUDERA_IMPALA = "weblogic.jdbc.impala.ImpalaDriver"
    AZURE_BILLING = "weblogic.jdbc.autorest.AutoRESTDriver"
    AZURE_SQL_DATABASE = "weblogic.jdbc.sqlserver.SQLServerDriver"
    AZURE_SYNAPSE_ANALYTICS = "weblogic.jdbc.sqlserver.SQLServerDriver"
    PIVOTAL_HD = "weblogic.jdbc.hive.HiveDriver"
    PIVOTAL_HDB = "weblogic.jdbc.greenplum.GreenplumDriver"
    IBM_DB2_WAREHOUSE = "weblogic.jdbc.db2.DB2Driver"
    IBM_DB2_HOSTED = "weblogic.jdbc.db2.DB2Driver"
    SAP_BW_4HANA = "weblogic.jdbc.s4hana.S4HanaDriver"
    SAP_NETWEAVER = "weblogic.jdbc.s4hana.S4HanaDriver"
    FINANCIALFORCE = "weblogic.jdbc.sforce.SForceDriver"
    VEEVA_CRM = "weblogic.jdbc.sforce.SForceDriver"
    DATASTAX = "weblogic.jdbc.cassandra.CassandraDriver"
    APACHE_HIVE = "weblogic.jdbc.hive.HiveDriver"
    CLOUDERA_CDH_HIVE = "weblogic.jdbc.hive.HiveDriver"
    HORTONWORKS_HIVE = "weblogic.jdbc.hive.HiveDriver"
    IBM_BIGINSIGHTS = "weblogic.jdbc.hive.HiveDriver"
    MAPR_HIVE = "weblogic.jdbc.hive.HiveDriver"
    AMAZON_EMR_HIVE = "weblogic.jdbc.hive.HiveDriver"
    AMAZON_AURORA = "weblogic.jdbc.postgresql.PostgreSQLDriver"
    ENTERPRISEDB = "weblogic.jdbc.postgresql.PostgreSQLDriver"
    SNOWFLAKE = "weblogic.jdbc.snowflake.SnowflakeDriver"
    GOOGLE_DRIVE = "weblogic.jdbc.autorest.AutoRESTDriver"
    AWS_S3 = "weblogic.jdbc.autorest.AutoRESTDriver"
    AZURE_COMPUTE = "weblogic.jdbc.autorest.AutoRESTDriver"
    AZURE_RESERVED_VM_INSTANCES = "weblogic.jdbc.autorest.AutoRESTDriver"
    AZURE_RESOURCE_HEALTH = "weblogic.jdbc.autorest.AutoRESTDriver"
    SAGE = "weblogic.jdbc.autorest.AutoRESTDriver"
    SQAURE = "weblogic.jdbc.autorest.AutoRESTDriver"
    WORDPRESS = "weblogic.jdbc.autorest.AutoRESTDriver"
    ZOHO_CRM = "weblogic.jdbc.autorest.AutoRESTDriver"
    AHREFS = "weblogic.jdbc.autorest.AutoRESTDriver"
    FOURSQUARE = "weblogic.jdbc.autorest.AutoRESTDriver"
    GOOGLE_ADSENSE = "weblogic.jdbc.autorest.AutoRESTDriver"
    GOOGLE_CALENDAR = "weblogic.jdbc.autorest.AutoRESTDriver"
    GOOGLE_CAMPAIGN_MANAGER = "weblogic.jdbc.autorest.AutoRESTDriver"
    GOOGLE_CONTACTS = "weblogic.jdbc.autorest.AutoRESTDriver"
    GOOGLE_SEARCH_ADS_360 = "weblogic.jdbc.autorest.AutoRESTDriver"
    KLAVIYO = "weblogic.jdbc.autorest.AutoRESTDriver"
    MAILCHIMP = "weblogic.jdbc.autorest.AutoRESTDriver"
    MARKETO = "weblogic.jdbc.autorest.AutoRESTDriver"
    PAYPAL = "weblogic.jdbc.autorest.AutoRESTDriver"
    QUICKBOOKS_ONLINE = "weblogic.jdbc.autorest.AutoRESTDriver"
    QUICKBOOKS_PAYMENTS = "weblogic.jdbc.autorest.AutoRESTDriver"
    QUORA_ADS = "weblogic.jdbc.autorest.AutoRESTDriver"
    SEMRUSH = "weblogic.jdbc.autorest.AutoRESTDriver"
    TUMBLR = "weblogic.jdbc.autorest.AutoRESTDriver"
    TWITTER = "weblogic.jdbc.autorest.AutoRESTDriver"
    VOLUSION = "weblogic.jdbc.autorest.AutoRESTDriver"
    WISTIA = "weblogic.jdbc.autorest.AutoRESTDriver"
    CONFLUENCE_CLOUD = "weblogic.jdbc.autorest.AutoRESTDriver"
    DOCUSIGN = "weblogic.jdbc.autorest.AutoRESTDriver"
    SALESFORCE_CHATTER = "weblogic.jdbc.autorest.AutoRESTDriver"
    STRIPE = "weblogic.jdbc.autorest.AutoRESTDriver"
    YELP = "weblogic.jdbc.autorest.AutoRESTDriver"
    ZOOM = "weblogic.jdbc.autorest.AutoRESTDriver"
    QMETRY = "weblogic.jdbc.autorest.AutoRESTDriver"
    SHOPIFY = "weblogic.jdbc.autorest.AutoRESTDriver"
    IBM_DB2_UDB = "weblogic.jdbc.db2.DB2Driver"
    SERVICENOW = "weblogic.jdbc.autorest.AutoRESTDriver"
